@@ -3,9 +3,9 @@ package com.sun.tools.jdeps.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "18.0.1.1+2" },
-            { "jdk", "18.0.1.1" },
-            { "release", "18.0.1.1" },
+            { "full", "18.0.2+0" },
+            { "jdk", "18.0.2" },
+            { "release", "18.0.2" },
         };
     }
 }
